/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Mock.java 18549 2009-09-09 08:49:38Z mancelin $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.back;

import java.io.IOException;
import java.io.PrintWriter;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;

/**
 * A mock class to add fake users.
 * 
 * @author mancelin
 */
public class Mock extends HttpServlet {

    /**
     * The EJB interface.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /** 
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();
        try {
            String jonas = "JOnAS";
            String version1 = "5.1.0-RC2";
            String version2 = "5.1.0-RC3";
            String version3 = "5.1.0-RC4";

            out.println("<html>");
            out.println("<head>");
            out.println("<title>JOnAS Users mock</title>");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"stylesheet\" type=\"text/css\"  />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"stylesheet\" type=\"text/css\" title=\"default\" />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"alternate stylesheet\" type=\"text/css\"  title=\"Alternate StyleSheet 1\" />");
            out.println("</head>");
            out.println("<body>");
            out.println("<div id=\"content\">");
            out.println("<a href=\"http://www.ow2.org/\">");
            out.println("<img src=\"/OW2ProductsService/header.jpg\""
                    + " alt=\"JOnAS header\" />");
            out.println("</a>");
            out.println("<div id=\"ow2logo\">");
            out.println("<a href=\"http://www.ow2.org\">");
            out.println("<img src=\"http://wiki.jonas.ow2.org/xwiki/bin/download/XWiki/MySkin/ow2_small.png\""
                    + " alt=\"OW2\" title=\"OW2\" />");
            out.println("</a>");
            out.println("</div>");
            out.println("<div id=\"communitylinks\">");
            out.println("<ul>");
            out.println("<li><a title=\"Users Map\" href=\"/OW2ProductsMap/\">Users Map</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a title=\"Admin\" href=\"/OW2ProductsService/mgmt.html\">Admin</a></li>");
            out.println("<li>|</li>");
             out.println("<li><a href=\"/OW2ProductsService/mgmt/showAll\">Manage records</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/manage\">Manage products</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/logout\">Logout</a></li>");
            out.println("</ul>");
            out.println("</div>");

            out.println("<h1 align=\"center\">Mock records added</h1>");
            out.println("<br/>");
            out.println("<br/>");
            out.println("<div align=\"center\">");
            out.println("<p>");
            /** add products in managed products **/
            out.println("Add new managed product : " + jonas + " " + version1 + "<br/>");
            clientSess.addManagedProduct(jonas, version1);
            out.println("Add new managed product : " + jonas + " " + version2 + "<br/>");
            clientSess.addManagedProduct(jonas, version2);
            out.println("Add new managed product : " + jonas + " " + version3 + "<br/>");
            clientSess.addManagedProduct(jonas, version3);

            /** add 43 records **/
            addNewRecord(out, "203.170.84.81", jonas, version1);
            addNewRecord(out, "203.170.84.82", jonas, version1);
            addNewRecord(out, "66.49.213.213", jonas, version3);
            addNewRecord(out, "85.190.27.2", jonas, version1);
            addNewRecord(out, "69.41.185.229", jonas, version2);
            addNewRecord(out, "85.190.27.2", jonas, version2);
            addNewRecord(out, "69.41.185.229", jonas, version1);
            addNewRecord(out, "69.41.185.225", jonas, version2);
            addNewRecord(out, "203.36.226.2", jonas, version1);
            addNewRecord(out, "85.190.27.2", jonas, version3);
            addNewRecord(out, "80.190.192.24", jonas, version2);
            addNewRecord(out, "80.190.192.24", jonas, version1);
            addNewRecord(out, "203.36.226.2", jonas, version3);
            addNewRecord(out, "80.190.192.29", jonas, version1);
            addNewRecord(out, "203.36.226.26", jonas, version3);

            addNewRecord(out, "207.171.166.53", jonas, version1);
            addNewRecord(out, "209.236.225.10", jonas, version3);
            addNewRecord(out, "209.236.225.10", jonas, version1);
            addNewRecord(out, "209.236.225.10", jonas, version2);
            addNewRecord(out, "207.171.166.53", jonas, version2);
            addNewRecord(out, "216.127.80.46", jonas, version1);
            addNewRecord(out, "216.127.80.46", jonas, version2);
            addNewRecord(out, "216.127.80.49", jonas, version1);
            addNewRecord(out, "207.171.166.53", jonas, version3);
            addNewRecord(out, "207.181.166.53", jonas, version2);
            addNewRecord(out, "207.171.166.56", jonas, version1);
            addNewRecord(out, "207.171.166.54", jonas, version3);
            addNewRecord(out, "209.236.224.10", jonas, version1);
            addNewRecord(out, "209.236.125.10", jonas, version3);

            addNewRecord(out, "213.186.33.18", jonas, version1);
            addNewRecord(out, "194.87.0.50", jonas, version3);
            addNewRecord(out, "164.100.56.202", jonas, version1);
            addNewRecord(out, "163.195.192.74", jonas, version2);
            addNewRecord(out, "161.148.24.13", jonas, version2);
            addNewRecord(out, "219.101.173.10", jonas, version1);
            addNewRecord(out, "213.214.146.50", jonas, version2);
            addNewRecord(out, "198.103.238.30", jonas, version1);
            addNewRecord(out, "194.177.252.107", jonas, version3);
            addNewRecord(out, "66.178.4.220", jonas, version2);
            addNewRecord(out, "163.247.56.17", jonas, version1);
            addNewRecord(out, "202.72.242.181", jonas, version3);
            addNewRecord(out, "203.162.1.145", jonas, version1);
            addNewRecord(out, "94.86.40.47", jonas, version3);

            /** add bad records not in managed products **/
            addNewRecord(out, "213.186.33.18", jonas, "9.0.0");
            addNewRecord(out, "198.103.238.30", jonas, "8.0.0");
            addNewRecord(out, "94.86.40.47", jonas, "7.0.0");


            out.println("<br/>");
            out.println("<br/>");
            out.println("</p>");
            out.println("</div>");
            out.println("</div>");
            out.println("</body>");
            out.println("</html>");
        } finally {
            out.close();
        }
    }

    /**
     * Add a new record in the app.
     * @param out the servlet printwriter
     * @param ip ip of the user
     * @param name name of the product
     * @param version version of the product
     */
    private void addNewRecord(final PrintWriter out,
            final String ip,
            final String name,
            final String version) {
        out.println("Add new record for @" + ip + " : " + name + " " + version + " - ");
        boolean success = clientSess.addNewRecord(ip, name, version, "test-geo@ow2.org",
                "", "", "", "", "", "", "", "", "");
        if (success) {
            out.println("OK");
        } else {
            out.println("KO");
        }
        out.println("<br/>");
    }

    /**
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
