/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ShowAll.java 18549 2009-09-09 08:49:38Z mancelin $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.back;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;
import org.ow2.util.geolocation.business.entity.GeolocalisedProduct;

/**
 * The management interface of the app.
 * 
 * @author mancelin
 */
public class ShowAll extends HttpServlet {

    /**
     * A null string.
     */
    private static final String NULL = "";
    /**
     * The geolocalization EJB.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();
        String ip = request.getParameter("ip");
        String productname = request.getParameter("productname");
        String productversion = request.getParameter("productversion");
        String email = request.getParameter("email");
        String product = request.getParameter("product");
        String ver = request.getParameter("version");
        String[] selected = request.getParameterValues("select");
        if (ip != null && productversion != null && productname != null) {
            if (email == null) {
                email = "";
            }
            clientSess.addNewRecord(ip, productname, productversion, email,
                    "", "", "", "", "", "", "", "", "");
        }
        if (selected != null) {
            if (selected.length > 0) {
                for (int i = 0; i < selected.length; i++) {
                    clientSess.removeProduct(Long.valueOf(selected[i]));
                }
            }
        }
        try {
            out.println("<html>");
            out.println("<head>");
            out.println("<title>OW2 Products Users records</title>");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + "rel=\"stylesheet\" type=\"text/css\"  />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\"" 
                    + "rel=\"stylesheet\" type=\"text/css\" title=\"default\" />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\"" 
                    + "rel=\"alternate stylesheet\" type=\"text/css\"  title=\"Alternate StyleSheet 1\" />");
            out.println("</head>");
            out.println("<body>");
            out.println("<div id=\"content\">");
            out.println("<a href=\"http://www.ow2.org/\">");
            out.println("<img src=\"/OW2ProductsService/header.jpg\""
                    + "alt=\"JOnAS header\" />");
            out.println("</a>");
            out.println("<div id=\"ow2logo\">");
            out.println("<a href=\"http://www.ow2.org\">");
            out.println("<img src=\"http://wiki.jonas.ow2.org/xwiki/bin/download/XWiki/MySkin/ow2_small.png\""
                    + "alt=\"OW2\" title=\"OW2\" />");
            out.println("</a>");
            out.println("</div>");
            out.println("<div id=\"communitylinks\">");
            out.println("<ul>");
            out.println("<li><a title=\"Users Map\" href=\"/OW2ProductsMap/\">Users Map</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a title=\"Admin\" href=\"/OW2ProductsService/mgmt.html\">Admin</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/showAll\">Manage records</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/manage\">Manage products</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/logout\">Logout</a></li>");
            out.println("</ul>");
            out.println("</div>");
            out.println("<h1 align=\"center\">OW2 Products Users records</h1>");
            out.println("<div align=\"center\">");
            out.println("<br/>");
            out.println("<br/>");
            out.println("<FORM method=post action=\"showAll\">");
            out.println("<TABLE ALIGN=\"middle\">");
            out.println("<TR>");
            out.println("<TD>product</TD>");
            out.println("<TD>");
            out.println("<SELECT name=\"product\">");
            out.println("<OPTION VALUE=\"all\">All</OPTION>");
            List names = clientSess.findAllProductsName();
            for (String name : (List<String>) names) {
                out.println("<OPTION VALUE=\"" + name);
                if (product != null && name.equals(product)) {
                    out.println(" selected=\"selected\"");
                }
                out.println("\">" + name + "</OPTION>");
            }
            out.println("</SELECT>");
            out.println("</TD>");
            out.println("<TD>version</TD>");
            out.println("<TD>");
            out.println("<SELECT name=\"version\">");
            out.println("<OPTION VALUE=\"all\">All</OPTION>");
            List versions = clientSess.findAllProductsVersions();
            for (String version : (List<String>) versions) {
                out.println("<OPTION VALUE=\"" + version);
                if (ver != null && version.equals(ver)) {
                    out.println(" selected=\"selected\"");
                }
                out.println("\">" + version + "</OPTION>");
            }
            out.println("</SELECT>");
            out.println("</TD>");
            out.println("<TD><INPUT type=\"submit\" value=\"Filter\"/></TD></TR>");
            out.println("</TABLE>");
            out.println("</FORM>");
            List productsList;
            if (product == null && ver == null) {
                productsList = clientSess.getLocalisedProducts(NULL, NULL);
            } else if (product.equals("all") && ver.equals("all")) {
                productsList = clientSess.getLocalisedProducts(NULL, NULL);
            } else if (product.equals("all") && !ver.equals("all")) {
                productsList = clientSess.getLocalisedProducts(NULL, ver);
            } else if (!product.equals("all") && ver.equals("all")) {
                productsList = clientSess.getLocalisedProducts(product, NULL);
            } else {
                productsList = clientSess.getLocalisedProducts(product, ver);
            }
            out.println("<FORM method=post action=\"showAll\">");
            out.println("<TABLE ALIGN=\"middle\">");
            out.println("<TR>");
            out.println("<TD>IP  <INPUT name=\"ip\" type=\"text\"></TD>");
            out.println("<TD>product name <INPUT name=\"productname\" type=\"text\"/></TD>");
            out.println("<TD>product version <INPUT name=\"productversion\" type=\"text\"/></TD>");
            out.println("<TD>email address <INPUT name=\"email\" type=\"text\"/></TD>");
            out.println("<TD><INPUT type=\"submit\" value=\"Add\"/></TD></TR></TABLE>");
            out.println("</FORM>");
            out.println("<FORM method=post action=\"showAll\">");
            out.println("<TABLE ALIGN=\"middle\">");
            out.println("<TR>");
            out.println("<TD>Remove selected products ");
            out.println("<TD><INPUT type=\"submit\" value=\"Remove\"/></TD></TR></TABLE>");
            out.println("<br/>");
            out.println("<TABLE BORDER=\"1\" ALIGN=\"middle\" CELLPADDING=5>");
            out.println("<TR BGCOLOR=\"#FFFFB0\">");
            out.println("<TH></TH>"); //Select </TH>");
            out.println("<TH> ID </TH>");
            out.println("<TH> Name </TH>");
            out.println("<TH> Version </TH>");
            out.println("<TH> IP </TH>");
            out.println("<TH> Email </TH>");
            out.println("<TH> Country </TH>");
            out.println("<TH> City </TH>");
            out.println("</TR>");
            for (GeolocalisedProduct p : (List<GeolocalisedProduct>) productsList) {
                out.println("<TR>");
                out.println("<TD align=\"center\"> <INPUT type=\"checkbox\" name=\"select\" value=\"" + p.getId() + "\"/></TD>");
                out.println("<TD align=\"center\"> <a href=\"/OW2ProductsService/mgmt/view?id="
                        + p.getId() + "\">" + p.getId() + "</a></TD>");
                out.println("<TD align=\"center\"> " + p.getProductName() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getProductVersion() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getIpAddress() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getEmail() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getCountryName() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getCity() + " </TD>");
                out.println("</TR>");
            }
            out.println("</TABLE>");
            out.println("<br/>");
            out.println("<br/>");
            out.println("</div>");
            out.println("</div>");
            out.println("</FORM>");
            out.println("</body>");
            out.println("</html>");
        } finally {
            out.close();
        }
    }
    /** 
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
